@@ -97,7 +97,7 @@ class Base:
         op = op.strip()
         if op.endswith('in'):
             assert isinstance(item, (list, tuple))
-            if settings.DB_TYPE == DBTYPE.SQLITE3:
+            if self._dbo.__dbtype__ == DBTYPE.SQLITE3:
                 self._where_args.extend(list(item))
                 return op + ' (%s)' % (",".join(["%s"] * len(item)))
             else:
@@ -433,7 +433,7 @@ class DBHelper:
         '''执行单个sql命令'''
         with self.connect_cur() as cur:
             if args:
-                if settings.DB_TYPE == DBTYPE.SQLITE3:
+                if self.__dbtype__ == DBTYPE.SQLITE3:
                     sql = sql.replace("%s", "?")
                 if not isinstance(args, (dict, tuple, list)):
                     args = tuple([args])
@@ -447,19 +447,19 @@ class DBHelper:
     def execute_insert(self, sql, args=None, isdict=True):
         '''执行单个sql命令'''
         with self.connect_cur() as cur:
-            if settings.DB_TYPE == DBTYPE.POSTGRESQL:
+            if self.__dbtype__ == DBTYPE.POSTGRESQL:
                 lower_sql = str(sql).lower()
                 if lower_sql.find('returning') == -1:
                     sql = '%s returning *' % sql
             if args:
-                if settings.DB_TYPE == DBTYPE.SQLITE3:
+                if self.__dbtype__ == DBTYPE.SQLITE3:
                     sql = sql.replace("%s", "?")
                 if not isinstance(args, (dict, tuple, list)):
                     args = tuple([args])
                 ret = cur.execute(sql, args)
             else:
                 ret = cur.execute(sql)
-            if settings.DB_TYPE == DBTYPE.POSTGRESQL:
+            if self.__dbtype__ == DBTYPE.POSTGRESQL:
                 res = cur.fetchone()
                 res = self.format_timestamp(res, cur)
                 if res and isdict:
@@ -477,7 +477,7 @@ class DBHelper:
         '''调用executemany执行多条命令'''
         with self.connect_cur() as cur:
             if args:
-                if settings.DB_TYPE == DBTYPE.SQLITE3:
+                if self.__dbtype__ == DBTYPE.SQLITE3:
                     sql = sql.replace("%s", "?")
                 if not isinstance(args, (dict, tuple, list)):
                     args = tuple([args])
@@ -498,7 +498,7 @@ class DBHelper:
             if not args:
                 cur.execute(sql)
             else:
-                if settings.DB_TYPE == DBTYPE.SQLITE3:
+                if self.__dbtype__ == DBTYPE.SQLITE3:
                     sql = sql.replace("%s", "?")
                 if not isinstance(args, (dict, tuple, list)):
                     args = tuple([args])
@@ -526,7 +526,7 @@ class DBHelper:
         '''
         with self.connect_cur() as cur:
             if args:
-                if settings.DB_TYPE == DBTYPE.SQLITE3:
+                if self.__dbtype__ == DBTYPE.SQLITE3:
                     sql = sql.replace("%s", "?")
                 if not isinstance(args, (dict, tuple, list)):
                     args = tuple([args])
@@ -599,11 +599,4 @@ class DBHelper:
         finally:
             pass
 
-    # def select_page(self, sql, pagecur=1, pagesize=20, count_sql=None, maxid=-1, isdict=True):
-    #     page = pager.db_pager(self, sql, pagecur, pagesize, count_sql, maxid)
-    #     if isdict:
-    #         page.todict()
-    #     else:
-    #         page.tolist()
-    #     return page
 
