@@ -137,7 +137,7 @@ class Table(object):
 
     @classmethod
     def _table(cls):
-        return "%s.%s" % (cls.__schema__(), cls.__table__)
+        return "%s.%s" % (cls.__schema__, cls.__table__)
 
     @classmethod
     def select(cls, **kwargs):
