@@ -44,7 +44,7 @@ def timeit(func):
 
             print(
                 'server=%s|id=%d|name=%s|user=%s|addr=%s:%d|db=%s|idle=%d|busy=%d|max=%d|trans=%d|time=%d|ret=%s|num=%d|sql=%s|err=%s' % (
-                conn.dbtype,
+                conn.__dbtype__,
                 conn.conn_id % 10000,
                 conn.name,
                 dbcf.get('user', ''),
@@ -121,7 +121,7 @@ def timesql(func):
                 if settings.POOL_TYPE == POOLTYPE.SIMPLE:
                     print(
                         'server=%s|id=%d|name=%s|user=%s|addr=%s:%d|db=%s|idle=%d|busy=%d|max=%d|trans=%d|time=%d|ret=%s|num=%d|sql=%s|args=%s|err=%s' % (
-                        self.dbtype,
+                        self.__dbtype__,
                         self._conn_id % 10000,
                         self._name,
                         dbcf.get('user', ''),
